@@ -94,18 +94,18 @@ for a particular mode of operation but not supplied."))
                      (cost-N condition) (cost-r condition) (cost-p condition))))
   (:documentation "Signaled when invalid Scrypt cost factors are provided to MAKE-KDF."))
 
-(define-condition unsupported-argon2i-parameters (ironclad-error)
+(define-condition unsupported-argon2-parameters (ironclad-error)
   ()
   (:report (lambda (condition stream)
-             (format stream "Argon2i parameters not supported. block-count must be at least 8, key-length must be at least 4, salt must be at least 8 bytes long and iteration-count must be at least 1.")))
-  (:documentation "Signaled when invalid Argon2i parameters are provided to MAKE-KDF."))
+             (format stream "Argon2 parameters not supported. block-count must be at least 8, key-length must be at least 4, salt must be at least 8 bytes long and iteration-count must be at least 1.")))
+  (:documentation "Signaled when invalid Argon2 parameters are provided to MAKE-KDF."))
 
 (define-condition insufficient-buffer-space (ironclad-error)
   ((buffer :initarg :buffer :reader insufficient-buffer-space-buffer)
    (start :initarg :start :reader insufficient-buffer-space-start)
    (length :initarg :length :reader insufficient-buffer-space-length))
   (:report (lambda (condition stream)
-             (format stream "Buffer ~A cannot accomodate ~D elements starting at index ~D."
+             (format stream "Buffer ~A cannot accommodate ~D elements starting at index ~D."
                      (insufficient-buffer-space-buffer condition)
                      (insufficient-buffer-space-length condition)
                      (insufficient-buffer-space-start condition))))
