@@ -1,9 +1,12 @@
 ;;;; -*- mode: lisp; indent-tabs-mode: nil -*-
 (in-package :crypto)
 
-
+
 ;;; PBKDF1 from RFC 2898, section 5.1
 
+(defclass pbkdf1 ()
+  ((digest :reader kdf-digest)))
+
 (defmethod shared-initialize :after ((kdf pbkdf1) slot-names &rest initargs
                                      &key digest &allow-other-keys)
   (declare (ignore slot-names initargs))
@@ -47,9 +50,12 @@
      finally
        (return (subseq key 0 (min key-length (length key))))))
 
-
+
 ;;; PBKDF2, from RFC 2898, section 5.2
 
+(defclass pbkdf2 ()
+  ((digest-name :initarg :digest :reader kdf-digest)))
+
 (defun pbkdf2-derive-key (digest passphrase salt iteration-count key-length)
   (check-type iteration-count (integer 1 *))
   (check-type key-length (integer 1 *))
