@@ -427,13 +427,8 @@
              name n d input output))))
 
 (defun elgamal-encryption-test (name p g x y input k output)
-  ;; Redefine elgamal-generate-k to use a defined K for the test instead of a random one
-  (setf (symbol-function 'ironclad::elgamal-generate-k)
-        (lambda (p)
-          (declare (ignore p))
-          k))
-
-  (let* ((pk (ironclad:make-public-key :elgamal :p p :g g :y y))
+  (let* ((ironclad::*signature-nonce-for-test* k)
+         (pk (ironclad:make-public-key :elgamal :p p :g g :y y))
          (sk (ironclad:make-private-key :elgamal :p p :g g :x x :y y))
          (c (ironclad:encrypt-message pk input))
          (m (ironclad:decrypt-message sk output)))
@@ -474,13 +469,8 @@
              name n e input signature))))
 
 (defun elgamal-signature-test (name p g x y input k signature)
-  ;; Redefine elgamal-generate-k to use a defined K for the test instead of a random one
-  (setf (symbol-function 'ironclad::elgamal-generate-k)
-        (lambda (p)
-          (declare (ignore p))
-          k))
-
-  (let* ((pk (ironclad:make-public-key :elgamal :p p :g g :y y))
+  (let* ((ironclad::*signature-nonce-for-test* k)
+         (pk (ironclad:make-public-key :elgamal :p p :g g :y y))
          (sk (ironclad:make-private-key :elgamal :p p :g g :x x :y y))
          (s (ironclad:sign-message sk input)))
     (when (mismatch s signature)
@@ -491,13 +481,8 @@
              name p g y input signature))))
 
 (defun dsa-signature-test (name p q g x y input k signature)
-  ;; Redefine dsa-generate-k to use a defined K for the test instead of a random one
-  (setf (symbol-function 'ironclad::dsa-generate-k)
-        (lambda (q)
-          (declare (ignore q))
-          k))
-
-  (let* ((sk (ironclad:make-private-key :dsa :p p :q q :g g :x x :y y))
+  (let* ((ironclad::*signature-nonce-for-test* k)
+         (sk (ironclad:make-private-key :dsa :p p :q q :g g :x x :y y))
          (pk (ironclad:make-public-key :dsa :p p :q q :g g :y y))
          (s (ironclad:sign-message sk input)))
     (when (mismatch s signature)
@@ -529,6 +514,54 @@
       (error "signature verification failed for ~A on pkey ~A, input ~A, signature ~A"
              name pkey input signature))))
 
+(defun secp256k1-signature-test (name skey pkey input k signature)
+  (let* ((ironclad::*signature-nonce-for-test* k)
+         (sk (ironclad:make-private-key :secp256k1 :x skey :y pkey))
+         (pk (ironclad:make-public-key :secp256k1 :y pkey))
+         (s (ironclad:sign-message sk input)))
+    (when (mismatch s signature)
+      (error "signature failed for ~A on skey ~A, input ~A, signature ~A"
+             name skey input signature))
+    (unless (ironclad:verify-signature pk input signature)
+      (error "signature verification failed for ~A on pkey ~A, input ~A, signature ~A"
+             name pkey input signature))))
+
+(defun secp256r1-signature-test (name skey pkey input k signature)
+  (let* ((ironclad::*signature-nonce-for-test* k)
+         (sk (ironclad:make-private-key :secp256r1 :x skey :y pkey))
+         (pk (ironclad:make-public-key :secp256r1 :y pkey))
+         (s (ironclad:sign-message sk input)))
+    (when (mismatch s signature)
+      (error "signature failed for ~A on skey ~A, input ~A, signature ~A"
+             name skey input signature))
+    (unless (ironclad:verify-signature pk input signature)
+      (error "signature verification failed for ~A on pkey ~A, input ~A, signature ~A"
+             name pkey input signature))))
+
+(defun secp384r1-signature-test (name skey pkey input k signature)
+  (let* ((ironclad::*signature-nonce-for-test* k)
+         (sk (ironclad:make-private-key :secp384r1 :x skey :y pkey))
+         (pk (ironclad:make-public-key :secp384r1 :y pkey))
+         (s (ironclad:sign-message sk input)))
+    (when (mismatch s signature)
+      (error "signature failed for ~A on skey ~A, input ~A, signature ~A"
+             name skey input signature))
+    (unless (ironclad:verify-signature pk input signature)
+      (error "signature verification failed for ~A on pkey ~A, input ~A, signature ~A"
+             name pkey input signature))))
+
+(defun secp521r1-signature-test (name skey pkey input k signature)
+  (let* ((ironclad::*signature-nonce-for-test* k)
+         (sk (ironclad:make-private-key :secp521r1 :x skey :y pkey))
+         (pk (ironclad:make-public-key :secp521r1 :y pkey))
+         (s (ironclad:sign-message sk input)))
+    (when (mismatch s signature)
+      (error "signature failed for ~A on skey ~A, input ~A, signature ~A"
+             name skey input signature))
+    (unless (ironclad:verify-signature pk input signature)
+      (error "signature verification failed for ~A on pkey ~A, input ~A, signature ~A"
+             name pkey input signature))))
+
 (defun curve25519-dh-test (name skey1 pkey1 skey2 pkey2 shared-secret)
   (let* ((sk1 (ironclad:make-private-key :curve25519 :x skey1 :y pkey1))
          (pk1 (ironclad:make-public-key :curve25519 :y pkey1))
@@ -571,6 +604,62 @@
       (error "shared secret computation failed for ~A on skey ~A, pkey ~A, secret ~A"
              name skey2 pkey1 shared-secret))))
 
+(defun secp256k1-dh-test (name skey1 pkey1 skey2 pkey2 shared-secret)
+  (let* ((sk1 (ironclad:make-private-key :secp256k1 :x skey1 :y pkey1))
+         (pk1 (ironclad:make-public-key :secp256k1 :y pkey1))
+         (sk2 (ironclad:make-private-key :secp256k1 :x skey2 :y pkey2))
+         (pk2 (ironclad:make-public-key :secp256k1 :y pkey2))
+         (ss1 (ironclad:diffie-hellman sk1 pk2))
+         (ss2 (ironclad:diffie-hellman sk2 pk1)))
+    (when (mismatch ss1 shared-secret)
+      (error "shared secret computation failed for ~A on skey ~A, pkey ~A, secret ~A"
+             name skey1 pkey2 shared-secret))
+    (when (mismatch ss2 shared-secret)
+      (error "shared secret computation failed for ~A on skey ~A, pkey ~A, secret ~A"
+             name skey2 pkey1 shared-secret))))
+
+(defun secp256r1-dh-test (name skey1 pkey1 skey2 pkey2 shared-secret)
+  (let* ((sk1 (ironclad:make-private-key :secp256r1 :x skey1 :y pkey1))
+         (pk1 (ironclad:make-public-key :secp256r1 :y pkey1))
+         (sk2 (ironclad:make-private-key :secp256r1 :x skey2 :y pkey2))
+         (pk2 (ironclad:make-public-key :secp256r1 :y pkey2))
+         (ss1 (ironclad:diffie-hellman sk1 pk2))
+         (ss2 (ironclad:diffie-hellman sk2 pk1)))
+    (when (mismatch ss1 shared-secret)
+      (error "shared secret computation failed for ~A on skey ~A, pkey ~A, secret ~A"
+             name skey1 pkey2 shared-secret))
+    (when (mismatch ss2 shared-secret)
+      (error "shared secret computation failed for ~A on skey ~A, pkey ~A, secret ~A"
+             name skey2 pkey1 shared-secret))))
+
+(defun secp384r1-dh-test (name skey1 pkey1 skey2 pkey2 shared-secret)
+  (let* ((sk1 (ironclad:make-private-key :secp384r1 :x skey1 :y pkey1))
+         (pk1 (ironclad:make-public-key :secp384r1 :y pkey1))
+         (sk2 (ironclad:make-private-key :secp384r1 :x skey2 :y pkey2))
+         (pk2 (ironclad:make-public-key :secp384r1 :y pkey2))
+         (ss1 (ironclad:diffie-hellman sk1 pk2))
+         (ss2 (ironclad:diffie-hellman sk2 pk1)))
+    (when (mismatch ss1 shared-secret)
+      (error "shared secret computation failed for ~A on skey ~A, pkey ~A, secret ~A"
+             name skey1 pkey2 shared-secret))
+    (when (mismatch ss2 shared-secret)
+      (error "shared secret computation failed for ~A on skey ~A, pkey ~A, secret ~A"
+             name skey2 pkey1 shared-secret))))
+
+(defun secp521r1-dh-test (name skey1 pkey1 skey2 pkey2 shared-secret)
+  (let* ((sk1 (ironclad:make-private-key :secp521r1 :x skey1 :y pkey1))
+         (pk1 (ironclad:make-public-key :secp521r1 :y pkey1))
+         (sk2 (ironclad:make-private-key :secp521r1 :x skey2 :y pkey2))
+         (pk2 (ironclad:make-public-key :secp521r1 :y pkey2))
+         (ss1 (ironclad:diffie-hellman sk1 pk2))
+         (ss2 (ironclad:diffie-hellman sk2 pk1)))
+    (when (mismatch ss1 shared-secret)
+      (error "shared secret computation failed for ~A on skey ~A, pkey ~A, secret ~A"
+             name skey1 pkey2 shared-secret))
+    (when (mismatch ss2 shared-secret)
+      (error "shared secret computation failed for ~A on skey ~A, pkey ~A, secret ~A"
+             name skey2 pkey1 shared-secret))))
+
 (defparameter *public-key-encryption-tests*
   (list (cons :rsa-oaep-encryption-test 'rsa-oaep-encryption-test)
         (cons :elgamal-encryption-test 'elgamal-encryption-test)))
@@ -580,12 +669,20 @@
         (cons :elgamal-signature-test 'elgamal-signature-test)
         (cons :dsa-signature-test 'dsa-signature-test)
         (cons :ed25519-signature-test 'ed25519-signature-test)
-        (cons :ed448-signature-test 'ed448-signature-test)))
+        (cons :ed448-signature-test 'ed448-signature-test)
+        (cons :secp256k1-signature-test 'secp256k1-signature-test)
+        (cons :secp256r1-signature-test 'secp256r1-signature-test)
+        (cons :secp384r1-signature-test 'secp384r1-signature-test)
+        (cons :secp521r1-signature-test 'secp521r1-signature-test)))
 
 (defparameter *public-key-diffie-hellman-tests*
   (list (cons :curve25519-dh-test 'curve25519-dh-test)
         (cons :curve448-dh-test 'curve448-dh-test)
-        (cons :elgamal-dh-test 'elgamal-dh-test)))
+        (cons :elgamal-dh-test 'elgamal-dh-test)
+        (cons :secp256k1-dh-test 'secp256k1-dh-test)
+        (cons :secp256r1-dh-test 'secp256r1-dh-test)
+        (cons :secp384r1-dh-test 'secp384r1-dh-test)
+        (cons :secp521r1-dh-test 'secp521r1-dh-test)))
 
 
 ;;; authenticated encryption testing routines
